Module collate

Module collate 

Collate - Batch Assembly Functions

File

crates/axonml-data/src/collate.rs

Author

Andrew Jewell Sr - AutomataNexus

Updated

March 8, 2026

Disclaimer

Use at own risk. This software is provided “as is”, without warranty of any kind, express or implied. The author and AutomataNexus shall not be held liable for any damages arising from the use of this software.

Structs

DefaultCollate
Default collation strategy that stacks tensors.
StackCollate
Collation that stacks tensors along a new batch dimension.

Traits

Collate
Trait for collating samples into batches.

Functions

concat_tensors
Concatenates tensors along an existing dimension.
stack_tensors
Stacks a vector of tensors along dimension 0.