Module dataloader

Module dataloader 

DataLoader - Batched Data Iteration

File

crates/axonml-data/src/dataloader.rs

Author

Andrew Jewell Sr. — AutomataNexus LLC ORCID: 0009-0005-2158-7060

Updated

April 14, 2026 11:15 PM EST

Disclaimer

Use at own risk. This software is provided “as is”, without warranty of any kind, express or implied. The author and AutomataNexus shall not be held liable for any damages arising from the use of this software.

Structs

Batch
A batch of data from the DataLoader.
DataLoader
DataLoader for batched iteration over datasets.
DataLoaderIter
Iterator over batches from a DataLoader.
GenericDataLoader
A more flexible DataLoader that works with any Dataset and Collate function.
GenericDataLoaderIter
Iterator for GenericDataLoader.
GpuPrefetchIter
A wrapper iterator that prefetches batches onto a GPU device in a background thread, overlapping CPU data loading with GPU computation.