Module dataset

Module dataset 

Dataset Trait - Core Data Abstraction

File

crates/axonml-data/src/dataset.rs

Author

Andrew Jewell Sr - AutomataNexus

Updated

March 8, 2026

Disclaimer

Use at own risk. This software is provided “as is”, without warranty of any kind, express or implied. The author and AutomataNexus shall not be held liable for any damages arising from the use of this software.

Structs

ConcatDataset
A dataset that concatenates multiple datasets.
InMemoryDataset
A simple in-memory dataset from a vector.
MapDataset
A dataset that applies a transform to another dataset.
SubsetDataset
A dataset that provides a subset of another dataset.
TensorDataset
A dataset wrapping tensors.

Traits

Dataset
Core trait for all datasets.